==> alfresco-data-model-23.7.0.15-sources.jar: org/alfresco/service/namespace/NamespacePrefixResolverProvider.java <==
/*
 * #%L
 * Alfresco Data model classes
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.service.namespace;

import java.io.Serializable;

/**
 * Provides support for serializable objects such as the QNameMap that require a
 * NamespacePrefixResolver to be available. Ensures that the objects can remain
 * serializable themselves and still maintain a valid NamespacePrefixResolver.
 * 
 * @author Kevin Roast
 */
public interface NamespacePrefixResolverProvider extends Serializable
{
    /**
     * Get an object that implements the NamespacePrefixResolver interface
     * 
     * @return NamespacePrefixResolver
     */
    NamespacePrefixResolver getNamespacePrefixResolver();
}

==> alfresco-data-model-25.4.0.9-sources.jar: org/alfresco/service/namespace/NamespacePrefixResolverProvider.java <==
/*
 * #%L
 * Alfresco Data model classes
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.service.namespace;

import java.io.Serializable;

/**
 * Provides support for serializable objects such as the QNameMap that require a NamespacePrefixResolver to be available. Ensures that the objects can remain serializable themselves and still maintain a valid NamespacePrefixResolver.
 * 
 * @author Kevin Roast
 */
public interface NamespacePrefixResolverProvider extends Serializable
{
    /**
     * Get an object that implements the NamespacePrefixResolver interface
     * 
     * @return NamespacePrefixResolver
     */
    NamespacePrefixResolver getNamespacePrefixResolver();
}
